pub struct Entry { /* private fields */ }Expand description
Configuration entry for a specific set of file specs (i.e. globs).
Defines what text patterns (“needles”) are forbidden to occur in the files’ content, as well as those which are required to be present.
Implementations
Sourceimpl Entry
impl Entry
pub fn new( specs: impl IntoIterator<Item = FileSpec>, forbid: impl IntoIterator<Item = Needle>, mandate: impl IntoIterator<Item = Needle>, ) -> Result<Self, EntryError>
Sourceimpl Entry
impl Entry
Sourcepub fn applies_to(&self, path: impl AsRef<Path>) -> bool
pub fn applies_to(&self, path: impl AsRef<Path>) -> bool
Check whether this Entry applies to the specified file path.
Sourcepub fn iter_forbidden_needles(&self) -> impl Iterator<Item = &Needle>
pub fn iter_forbidden_needles(&self) -> impl Iterator<Item = &Needle>
Iterate over forbidden needles in this entry.
Sourcepub fn forbidden_needle(&self, idx: usize) -> Option<&Needle>
pub fn forbidden_needle(&self, idx: usize) -> Option<&Needle>
Get a forbidden needle in this entry by index.
Sourcepub fn forbidden_needle_count(&self) -> usize
pub fn forbidden_needle_count(&self) -> usize
Count of forbidden/banned needles in this entry.
Sourcepub fn iter_mandated_needles(&self) -> impl Iterator<Item = &Needle>
pub fn iter_mandated_needles(&self) -> impl Iterator<Item = &Needle>
Iterate over mandates needles in this entry.
Sourcepub fn mandated_needle(&self, idx: usize) -> Option<&Needle>
pub fn mandated_needle(&self, idx: usize) -> Option<&Needle>
Get a mandated needle in this entry by index.
Sourcepub fn mandated_needle_count(&self) -> usize
pub fn mandated_needle_count(&self) -> usize
Count of mandated/required needles in this entry.